@@ -98,13 +98,13 @@ from sphinx.application import Sphinx
 from sphinx.util import split_explicit_title
 from sphinx.writers.html import HTMLTranslator
 
-__all__ = [
+__all__ = (
 		"asset_role",
 		"AssetNode",
 		"visit_asset_node",
 		"depart_asset_node",
 		"setup",
-		]
+		)
 
 # this package
 from sphinx_toolbox.utils import SphinxExtMetadata, metadata_add_version
@@ -159,7 +159,7 @@ def asset_role(
 	return [node], []
 
 
-def visit_asset_node(translator: HTMLTranslator, node: AssetNode):
+def visit_asset_node(translator: HTMLTranslator, node: AssetNode) -> None:
 	"""
 	Visit an :class:`~.AssetNode`.
 
@@ -195,7 +195,7 @@ def visit_asset_node(translator: HTMLTranslator, node: AssetNode):
 	translator.context.append("</a>")
 
 
-def depart_asset_node(translator: HTMLTranslator, node: AssetNode):
+def depart_asset_node(translator: HTMLTranslator, node: AssetNode) -> None:
 	"""
 	Depart an :class:`~.AssetNode`.
 
