@@ -147,7 +147,6 @@ from docutils.nodes import Node, system_message
 from domdf_python_tools.paths import PathPlus
 from domdf_python_tools.stringlist import StringList
 from sphinx.application import Sphinx
-from sphinx.config import Config
 from sphinx.ext.autodoc import UNINITIALIZED_ATTR, ModuleDocumenter
 from sphinx.util import texescape
 from sphinx.util.docutils import SphinxRole
@@ -156,9 +155,9 @@ from sphinx.writers.html import HTMLTranslator
 # this package
 from sphinx_toolbox import _css
 from sphinx_toolbox.more_autodoc.variables import VariableDocumenter
-from sphinx_toolbox.utils import SphinxExtMetadata, add_nbsp_substitution, flag, metadata_add_version
+from sphinx_toolbox.utils import Config, SphinxExtMetadata, add_nbsp_substitution, flag, metadata_add_version
 
-__all__ = [
+__all__ = (
 		"RegexDocumenter",
 		"RegexParser",
 		"TerminalRegexParser",
@@ -170,7 +169,7 @@ __all__ = [
 		"latex_textcolor",
 		"copy_asset_files",
 		"setup",
-		]
+		)
 
 
 class RegexDocumenter(VariableDocumenter):
@@ -208,7 +207,7 @@ class RegexDocumenter(VariableDocumenter):
 
 		return isinstance(parent, ModuleDocumenter) and isattr and isinstance(member, Pattern)
 
-	def add_content(self, more_content: Any, no_docstring: bool = False):
+	def add_content(self, more_content: Any, no_docstring: bool = False) -> None:
 		"""
 		Add content from docstrings, attribute documentation and the user.
 
@@ -242,7 +241,7 @@ class RegexDocumenter(VariableDocumenter):
 				docstrings.append([])
 
 			if docstrings == [["Compiled regular expression objects", '']] or docstrings == [[]]:
-				docstrings = [["Compiled regular expression object.", '']]
+				docstrings = [["Compiled regular expression object.", '']]  # pylint: disable=W8301
 
 			for i, line in enumerate(self.process_doc(docstrings)):
 				self.add_line(line, sourcename, i)
@@ -308,7 +307,7 @@ class RegexDocumenter(VariableDocumenter):
 
 			self.add_line('', sourcename)
 
-	def add_directive_header(self, sig: str):
+	def add_directive_header(self, sig: str) -> None:
 		"""
 		Add the directive's header.
 
@@ -400,7 +399,7 @@ class RegexParser:
 
 		buf = []
 
-		def _parse_pattern(pattern):
+		def _parse_pattern(pattern) -> None:  # noqa: MAN001
 
 			for what, content in pattern:
 				# print(what, content)
@@ -525,7 +524,7 @@ class RegexParser:
 		trailing_spaces = len(tuple(itertools.takewhile(str.isspace, pattern[::-1])))
 		pattern = pattern.strip(' ')
 
-		tokens: List = list(sre_parse.parse(pattern, regex.flags))  # type: ignore
+		tokens: List = list(sre_parse.parse(pattern, regex.flags))  # type: ignore[call-overload]
 
 		if not leading_spaces:
 			while tokens[0] == (LITERAL, ord(' ')):
@@ -703,23 +702,23 @@ class TerminalRegexParser(RegexParser):
 	# Colours
 
 	@staticmethod
-	def AT_COLOUR(s):  # noqa: D102
+	def AT_COLOUR(s: str) -> str:  # noqa: D102
 		return f"\x1b[33m{s}\x1b[39m"
 
 	@staticmethod
-	def SUBPATTERN_COLOUR(s):  # noqa: D102
+	def SUBPATTERN_COLOUR(s: str) -> str:  # noqa: D102
 		return f"\x1b[93m{s}\x1b[39m"
 
 	@staticmethod
-	def IN_COLOUR(s):  # noqa: D102
+	def IN_COLOUR(s: str) -> str:  # noqa: D102
 		return f"\x1b[91m{s}\x1b[39m"
 
 	@staticmethod
-	def REPEAT_COLOUR(s):  # noqa: D102
+	def REPEAT_COLOUR(s: str) -> str:  # noqa: D102
 		return f"\x1b[94m{s}\x1b[39m"
 
 	@staticmethod
-	def LITERAL_COLOUR(s):  # noqa: D102
+	def LITERAL_COLOUR(s: str) -> str:  # noqa: D102
 		return f"\x1b[32m{s}\x1b[39m"
 
 	REPEAT_BRACE_COLOUR = BRANCH_COLOUR = ANY_COLOUR = AT_COLOUR
@@ -731,7 +730,7 @@ class RegexNode(nodes.literal):
 	Docutils Node to show a highlighted regular expression.
 	"""
 
-	def __init__(self, rawsource='', text='', *children, **attributes):
+	def __init__(self, rawsource: str = '', text: str = '', *children, **attributes) -> None:
 		super().__init__(rawsource, text, *children, **attributes)
 		self.pattern = re.compile(':'.join(rawsource.split(':')[2:])[1:-1])
 
@@ -751,7 +750,7 @@ class Regex(SphinxRole):
 		return [RegexNode(self.rawtext, self.text, **options)], []
 
 
-def visit_regex_node(translator: HTMLTranslator, node: RegexNode):
+def visit_regex_node(translator: HTMLTranslator, node: RegexNode) -> None:
 	"""
 	Visit an :class:`~.RegexNode`.
 
@@ -762,7 +761,7 @@ def visit_regex_node(translator: HTMLTranslator, node: RegexNode):
 	translator.body.append(regex_parser.parse_pattern(node.pattern))
 
 
-def depart_regex_node(translator: HTMLTranslator, node: RegexNode):
+def depart_regex_node(translator: HTMLTranslator, node: RegexNode) -> None:
 	"""
 	Depart an :class:`~.RegexNode`.
 
@@ -773,7 +772,7 @@ def depart_regex_node(translator: HTMLTranslator, node: RegexNode):
 	translator.body.pop(-1)
 
 
-def visit_regex_node_latex(translator: HTMLTranslator, node: RegexNode):
+def visit_regex_node_latex(translator: HTMLTranslator, node: RegexNode) -> None:
 	"""
 	Visit an :class:`~.RegexNode` with the LaTeX builder.
 
@@ -786,7 +785,7 @@ def visit_regex_node_latex(translator: HTMLTranslator, node: RegexNode):
 	translator.body.append(latex_regex_parser.parse_pattern(node.pattern))
 
 
-def depart_regex_node_latex(translator: HTMLTranslator, node: RegexNode):
+def depart_regex_node_latex(translator: HTMLTranslator, node: RegexNode) -> None:
 	"""
 	Depart an :class:`~.RegexNode` with the LaTeX builder.
 
@@ -799,7 +798,7 @@ def depart_regex_node_latex(translator: HTMLTranslator, node: RegexNode):
 	translator.body.pop(-1)
 
 
-def copy_asset_files(app: Sphinx, exception: Optional[Exception] = None):
+def copy_asset_files(app: Sphinx, exception: Optional[Exception] = None) -> None:
 	"""
 	Copy additional stylesheets into the HTML build directory.
 
@@ -822,7 +821,7 @@ regex_parser = HTMLRegexParser()
 latex_regex_parser = LaTeXRegexParser()
 
 
-def configure(app: Sphinx, config: Config):
+def configure(app: Sphinx, config: Config) -> None:
 	"""
 	Configure :mod:`sphinx_toolbox.code`.
 
@@ -847,7 +846,7 @@ def configure(app: Sphinx, config: Config):
 	latex_preamble.append(r"\definecolor{regex_any}{HTML}{FF4500}")
 
 	latex_elements["preamble"] = str(latex_preamble)
-	app.config.latex_elements = latex_elements  # type: ignore
+	app.config.latex_elements = latex_elements  # type: ignore[attr-defined]
 	add_nbsp_substitution(config)
 
 
