@@ -132,7 +132,7 @@ from sphinx_toolbox._data_documenter import DataDocumenter
 from sphinx_toolbox.more_autodoc.typehints import _resolve_forwardref, format_annotation
 from sphinx_toolbox.utils import SphinxExtMetadata, add_nbsp_substitution, flag, metadata_add_version
 
-__all__ = [
+__all__ = (
 		"VariableDocumenter",
 		"TypedAttributeDocumenter",
 		"InstanceAttributeDocumenter",
@@ -140,7 +140,7 @@ __all__ = [
 		"type_template",
 		"get_variable_type",
 		"setup",
-		]
+		)
 
 
 def get_variable_type(documenter: Documenter) -> str:
@@ -214,7 +214,10 @@ class VariableDocumenter(DataDocumenter):
 
 	directivetype = "data"
 	objtype = "variable"
-	priority: float = DataDocumenter.priority + 0.5  # type: ignore  # keeps it below TypeVarDocumenter
+
+	# keeps it below TypeVarDocumenter
+	priority: float = DataDocumenter.priority + 0.5  # type: ignore[assignment]
+
 	option_spec = {
 			"no-value": flag,
 			"no-type": flag,
@@ -228,7 +231,7 @@ class VariableDocumenter(DataDocumenter):
 		self.options = Options(self.options.copy())
 		add_nbsp_substitution(self.env.app.config)
 
-	def add_directive_header(self, sig: str):
+	def add_directive_header(self, sig: str) -> None:
 		"""
 		Add the directive's header.
 
@@ -383,7 +386,7 @@ class TypedAttributeDocumenter(DocstringStripSignatureMixin, ClassLevelDocumente
 
 		return self.get_attr(self.parent or self.object, "__module__", None) or self.modname
 
-	def add_directive_header(self, sig: str):
+	def add_directive_header(self, sig: str) -> None:
 		"""
 		Add the directive's header.
 
@@ -553,7 +556,7 @@ class InstanceAttributeDocumenter(TypedAttributeDocumenter):
 		self._datadescriptor = False
 		return True
 
-	def add_content(self, more_content: Any, no_docstring: bool = False):
+	def add_content(self, more_content: Any, no_docstring: bool = False) -> None:
 		"""
 		Never try to get a docstring from the object.
 		"""
