@@ -184,16 +184,16 @@ else:
 	# 3rd party
 	from sphinx.util.docstrings import extract_metadata
 
-__all__ = [
+__all__ = (
 		"PatchedAutosummary",
 		"PatchedAutoSummModuleDocumenter",
 		"PatchedAutoSummClassDocumenter",
 		"get_documenter",
 		"setup",
-		]
+		)
 
 
-def add_autosummary(self, relative_ref_paths: bool = False):
+def add_autosummary(self, relative_ref_paths: bool = False) -> None:
 	"""
 	Add the :rst:dir:`autosummary` table of this documenter.
 
@@ -214,6 +214,16 @@ def add_autosummary(self, relative_ref_paths: bool = False):
 		content.append(".. latex:vspace:: 10px")
 		content.blankline()
 
+	member_order = get_first_matching(
+			lambda x: x != "groupwise",
+			(
+					self.options.get("member-order", ''),
+					self.env.config.autodocsumm_member_order,
+					self.env.config.autodoc_member_order,
+					),
+			default="alphabetical",
+			)
+
 	for section, documenters in grouped_documenters.items():
 		if not self.options.get("autosummary-no-titles", False):
 			content.append(f"**{section}:**")
@@ -231,16 +241,6 @@ def add_autosummary(self, relative_ref_paths: bool = False):
 
 		content.blankline(ensure_single=True)
 
-		member_order = get_first_matching(
-				lambda x: x != "groupwise",
-				[
-						self.options.get("member-order", ''),
-						self.env.config.autodocsumm_member_order,
-						self.env.config.autodoc_member_order,
-						],
-				default="alphabetical",
-				)
-
 		with content.with_indent_size(content.indent_size + 1):
 			for documenter, _ in self.sort_members(documenters, member_order):
 				obj_ref_path = documenter.fullname
@@ -425,6 +425,7 @@ class PatchedAutoSummModuleDocumenter(autodocsumm.AutoSummModuleDocumenter):
 			attr_docs = {}
 
 		doc: Optional[str]
+		sphinx_gt_41 = sphinx.version_info > (4, 1)
 
 		# process members and determine which to skip
 		for (membername, member) in members:
@@ -450,7 +451,7 @@ class PatchedAutoSummModuleDocumenter(autodocsumm.AutoSummModuleDocumenter):
 				if cls_doc == doc:
 					doc = None
 
-			if sphinx.version_info > (4, 1):
+			if sphinx_gt_41:
 				doc, metadata = separate_metadata(doc)  # type: ignore[arg-type]
 			else:
 				metadata = extract_metadata(doc)  # type: ignore[arg-type]
@@ -515,7 +516,7 @@ class PatchedAutoSummModuleDocumenter(autodocsumm.AutoSummModuleDocumenter):
 			# should be skipped
 			if self.env.app:
 				# let extensions preprocess docstrings
-				try:
+				try:  # pylint: disable=R8203
 					skip_user = self.env.app.emit_firstresult(
 							"autodoc-skip-member",
 							self.objtype,
@@ -556,9 +557,10 @@ class PatchedAutoSummModuleDocumenter(autodocsumm.AutoSummModuleDocumenter):
 			memberlist = self.options.members or []
 		ret = []
 		for mname in memberlist:
-			try:
+			try:  # pylint: disable=R8203
 				ret.append((mname, safe_getattr(self.object, mname)))
 			except AttributeError:
+				# pylint: disable=dotted-import-in-loop)
 				logger.warning(
 						operator.mod(
 								__("missing attribute mentioned in :members: or __all__: module %s, attribute %s"),
@@ -566,6 +568,7 @@ class PatchedAutoSummModuleDocumenter(autodocsumm.AutoSummModuleDocumenter):
 								),
 						type="autodoc"
 						)
+				# pylint: enable=dotted-import-in-loop)
 		return False, ret
 
 
@@ -577,7 +580,7 @@ class PatchedAutoSummClassDocumenter(autodocsumm.AutoSummClassDocumenter):
 	.. versionadded:: 0.9.0
 	"""  # noqa: D400
 
-	def add_content(self, *args, **kwargs):
+	def add_content(self, *args, **kwargs) -> None:
 		"""
 		Add content from docstrings, attribute documentation and user.
 		"""
@@ -595,7 +598,7 @@ class PatchedAutoDocSummDirective(autodocsumm.AutoDocSummDirective):
 	.. attention:: This class is not part of the public API.
 	"""
 
-	def run(self):
+	def run(self) -> List[nodes.Node]:
 		reporter = self.state.document.reporter
 
 		if hasattr(reporter, "get_source_and_line"):
