@@ -113,7 +113,7 @@ from sphinx_toolbox import latex
 from sphinx_toolbox.more_autosummary import PatchedAutosummary
 from sphinx_toolbox.utils import SphinxExtMetadata, metadata_add_version
 
-__all__ = ["AutosummaryWidths", "WidthsDirective", "configure", "setup"]
+__all__ = ("AutosummaryWidths", "WidthsDirective", "configure", "setup")
 
 
 class AutosummaryWidths(PatchedAutosummary):
@@ -157,7 +157,7 @@ class AutosummaryWidths(PatchedAutosummary):
 			for text in column_texts:
 				node = nodes.paragraph('')
 				vl = StringList()
-				vl.append(text, f"{source}:{line:d}:<autosummary>")
+				vl.append(text, f"{source}:{line:d}:<autosummary>")  # pylint: disable=loop-invariant-statement
 
 				with switch_source_input(self.state, vl):
 					self.state.nested_parse(vl, 0, node)
@@ -170,10 +170,11 @@ class AutosummaryWidths(PatchedAutosummary):
 
 			body.append(row)
 
+		add_signature = "nosignatures" not in self.options
 		for name, sig, summary, real_name in items:
 			col1 = f":obj:`{name} <{real_name}>`"
 
-			if "nosignatures" not in self.options:
+			if add_signature:
 				col1 += f"\\ {rst.escape(sig)}"
 
 			append_row(col1, summary)
@@ -214,12 +215,12 @@ class WidthsDirective(SphinxDirective):
 		Process the directive's arguments.
 		"""
 
-		self.state.document.autosummary_widths = self.parse_widths(self.arguments)  # type: ignore
+		self.state.document.autosummary_widths = self.parse_widths(self.arguments)  # type: ignore[attr-defined]
 
 		return []
 
 
-def configure(app: Sphinx, config: Config):
+def configure(app: Sphinx, config: Config) -> None:
 	"""
 	Configure :mod:`sphinx_toolbox.more_autosummary.column_widths`.
 
@@ -238,7 +239,7 @@ def configure(app: Sphinx, config: Config):
 	latex_preamble.blankline()
 
 	latex_elements["preamble"] = str(latex_preamble)
-	config.latex_elements = latex_elements  # type: ignore
+	config.latex_elements = latex_elements  # type: ignore[attr-defined]
 
 
 @metadata_add_version
